Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
Core CoreConfig `toml:"core"`
Web WebConfig `toml:"web"`
}
type CoreConfig ¶
type WebConfig ¶
type WebConfig struct {
// Domain should be the instance's full domain, including https:// but without the trailing slash.
Domain string `toml:"domain"`
// WebfingerDomain is the domain used for WebFinger lookups (and by extension, the part after the @ in usernames).
// If left empty, this defaults to the host part of Domain.
WebfingerDomain string `toml:"webfinger_domain"`
// Port is the port the server should listen on.
Port int `toml:"port"`
}
Click to show internal directories.
Click to hide internal directories.